@@ -104,8 +104,6 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList& args)
     setupView();
     setupActions();
 
-    connect(m_splitter, SIGNAL(splitterMoved(int, int)), SLOT(slotUpdateSplitterSizes()));
-
     connect(m_model, SIGNAL(loadingStarted()),
             this, SLOT(slotLoadingStarted()));
     connect(m_model, SIGNAL(loadingFinished(KJob *)),
@@ -132,6 +130,8 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList& args)
 
 Part::~Part()
 {
+    updateSplitterSizes();
+
     m_extractFilesAction->menu()->deleteLater();
 
     delete m_previewDir;
@@ -611,8 +611,6 @@ void Part::slotExtractFiles()
         //this is done to update the quick extract menu
         updateActions();
 
-        m_destinationDirectory = dialog.data()->destinationDirectory().pathOrUrl();
-
         QVariantList files;
 
         //if the user has chosen to extract only selected entries, fetch these
@@ -629,7 +627,10 @@ void Part::slotExtractFiles()
             options[QLatin1String("PreservePaths")] = true;
         }
 
-        ExtractJob *job = m_model->extractFiles(files, m_destinationDirectory, options);
+        options[QLatin1String("FollowExtractionDialogSettings")] = true;
+
+        const QString destinationDirectory = dialog.data()->destinationDirectory().pathOrUrl();
+        ExtractJob *job = m_model->extractFiles(files, destinationDirectory, options);
         registerJob(job);
 
         connect(job, SIGNAL(result(KJob*)),
@@ -691,11 +692,21 @@ void Part::slotExtractionDone(KJob* job)
     if (job->error()) {
         KMessageBox::error(widget(), job->errorString());
     } else {
-        if (ArkSettings::openDestinationFolderAfterExtraction()) {
-            KUrl destinationFolder(m_destinationDirectory);
-            destinationFolder.cleanPath();
+        ExtractJob *extractJob = qobject_cast<ExtractJob*>(job);
+        Q_ASSERT(extractJob);
 
-            KRun::runUrl(destinationFolder, QLatin1String( "inode/directory" ), widget());
+        const bool followExtractionDialogSettings =
+            extractJob->extractionOptions().value(QLatin1String("FollowExtractionDialogSettings"), false).toBool();
+        if (!followExtractionDialogSettings) {
+            return;
+        }
+
+        if (ArkSettings::openDestinationFolderAfterExtraction()) {
+
+            KUrl destinationDirectory(extractJob->destinationDirectory());
+            destinationDirectory.cleanPath();
+
+            KRun::runUrl(destinationDirectory, QLatin1String("inode/directory"), widget());
         }
 
         if (ArkSettings::closeAfterExtraction()) {
@@ -836,10 +847,10 @@ void Part::slotToggleInfoPanel(bool visible)
     }
 
     m_splitter->setSizes(splitterSizes);
-    slotUpdateSplitterSizes();
+    updateSplitterSizes();
 }
 
-void Part::slotUpdateSplitterSizes()
+void Part::updateSplitterSizes()
 {
     ArkSettings::setSplitterSizes(m_splitter->sizes());
     ArkSettings::self()->writeConfig();
