@@ -21,37 +21,37 @@
 #ifndef ALLYOURBASE_H
 #define ALLYOURBASE_H
 
-#include <k3iconview.h>
-#include <k3listview.h>
 #include <kwallet.h>
 #include <kiconloader.h>
 #include <kicontheme.h>
-//Added by qt3to4:
+#include <klistwidget.h>
 #include <QPixmap>
 #include <QDropEvent>
 #include <QDragEnterEvent>
 #include <QMouseEvent>
+#include <QTreeWidget>
 
 #define KWALLETENTRYMAGIC ((quint32) 0x6B776C65)
 #define KWALLETFOLDERMAGIC ((quint32) 0x6B776C66)
 
+class KUrl;
+
 enum KWalletListItemClasses {
-	KWalletFolderItemClass = 1000,
+	KWalletFolderItemClass = QTreeWidgetItem::UserType,
 	KWalletContainerItemClass,
 	KWalletEntryItemClass,
-	KWalletUnknownClass = 2000
+	KWalletUnknownClass
 };
 
-class KWalletEntryItem : public K3ListViewItem {
+class KWalletEntryItem : public QTreeWidgetItem {
 	public:
-		KWalletEntryItem(KWallet::Wallet *w, Q3ListViewItem* parent, const QString& ename);
+		KWalletEntryItem(KWallet::Wallet *w, QTreeWidgetItem* parent, const QString& ename);
 		virtual ~KWalletEntryItem();
 
 		const QString& oldName() { return _oldName; }
 		QString currentName() { return text(0); }
 
 		void clearOldName() { _oldName = text(0); }
-		virtual int rtti() const;
 
 	public:
 		KWallet::Wallet *_wallet;
@@ -60,37 +60,33 @@ class KWalletEntryItem : public K3ListViewItem {
 		QString _oldName;
 };
 
-class KWalletContainerItem : public K3ListViewItem {
+class KWalletContainerItem : public QTreeWidgetItem {
 	public:
-		KWalletContainerItem(Q3ListViewItem* parent, const QString& name,
-		    KWallet::Wallet::EntryType type);
+		KWalletContainerItem(QTreeWidgetItem* parent, const QString& name, KWallet::Wallet::EntryType entryType);
 		virtual ~KWalletContainerItem();
 
 	public:
-		virtual int rtti() const;
-		KWallet::Wallet::EntryType type();
+		KWallet::Wallet::EntryType entryType();
 		bool contains(const QString& itemKey);
-		Q3ListViewItem* getItem(const QString& itemKey);
+		QTreeWidgetItem* getItem(const QString& itemKey);
 
 	private:
 		KWallet::Wallet::EntryType _type;
 };
 
-class KWalletFolderItem : public K3ListViewItem {
+class KWalletFolderItem : public QTreeWidgetItem {
 	public:
-		KWalletFolderItem(KWallet::Wallet *w, Q3ListView* parent, 
-			const QString& name, int entries);
+		KWalletFolderItem(KWallet::Wallet *w, QTreeWidget* parent, const QString& name, int entries);
 		virtual ~KWalletFolderItem();
 
 		virtual bool acceptDrop(const QMimeSource *mime) const;
-		virtual int rtti() const;
 
 		QString name() const;
 		void refresh();
 		KWalletContainerItem* getContainer(KWallet::Wallet::EntryType type);
 		QPixmap getFolderIcon(KIconLoader::Group group);
 		bool contains(const QString& itemKey);
-		Q3ListViewItem* getItem(const QString& itemKey);
+		QTreeWidgetItem* getItem(const QString& itemKey);
 
 	public:
 		KWallet::Wallet *_wallet;
@@ -100,7 +96,7 @@ class KWalletFolderItem : public K3ListViewItem {
 		int _entries;
 };
 
-class KWalletEntryList : public K3ListView {
+class KWalletEntryList : public QTreeWidget {
 	Q_OBJECT
 
 	public:
@@ -109,52 +105,56 @@ class KWalletEntryList : public K3ListView {
 
 		bool existsFolder(const QString& name);
 		KWalletFolderItem* getFolder(const QString& name);
-		void contentsDropEvent(QDropEvent *e);
-		void contentsDragEnterEvent(QDragEnterEvent *e);
 		void setWallet(KWallet::Wallet *w);
 
 	protected:
-		void itemDropped(QDropEvent *e, Q3ListViewItem *item);
-		virtual Q3DragObject *dragObject();
-		virtual bool acceptDrag (QDropEvent* event) const;
+		virtual void dragEnterEvent(QDragEnterEvent *e);
+		virtual void dragMoveEvent(QDragMoveEvent *e);
+		virtual void dropEvent(QDropEvent *e);
+		virtual void mousePressEvent(QMouseEvent *e);
+		virtual void mouseMoveEvent(QMouseEvent *e);
+		
+		void itemDropped(QDropEvent *e, QTreeWidgetItem *item);
 
 	private:
-		static KWalletFolderItem *getItemFolder(Q3ListViewItem *item);
+		static KWalletFolderItem *getItemFolder(QTreeWidgetItem *item);
+		QMimeData *itemMimeData(const QTreeWidgetItem *i) const;
 	
 	public:
 		KWallet::Wallet *_wallet;
+		QPoint _mousePos;
 };
 
-class KWalletItem : public Q3IconViewItem {
+class KWalletItem : public QListWidgetItem {
 	public:
-		KWalletItem(Q3IconView *parent, const QString& walletName);
+		KWalletItem(QListWidget *parent, const QString& walletName);
 		virtual ~KWalletItem();
 
-		virtual bool acceptDrop(const QMimeSource *mime) const;
-		
 		void setOpen(bool state);
-
-	protected:
-		virtual void dropped(QDropEvent *e, const Q3ValueList<Q3IconDragItem>& lst); 
 		
+		void processDropEvent(QDropEvent *e);
+
 	private:
 		bool _open;
 };
 
 
-class KWalletIconView : public K3IconView {
+class KWalletIconView : public KListWidget {
 	Q_OBJECT
 
 	public:
-		explicit KWalletIconView(QWidget *parent, const char *name = 0L);
+		explicit KWalletIconView(QWidget *parent);
 		virtual ~KWalletIconView();
 
-	protected slots:
-		virtual void slotDropped(QDropEvent *e, const Q3ValueList<Q3IconDragItem>& lst);
-
 	protected:
-		virtual Q3DragObject *dragObject();
-		virtual void contentsMousePressEvent(QMouseEvent *e);
+		virtual void dragEnterEvent(QDragEnterEvent *e);
+		virtual void dragMoveEvent(QDragMoveEvent *e);
+		virtual void dropEvent(QDropEvent *e);
+		virtual void mousePressEvent(QMouseEvent *e);
+		virtual void mouseMoveEvent(QMouseEvent *e);
+	
+	private:
+		bool shouldIgnoreDropEvent(const QDropEvent *e, KUrl *u, QListWidgetItem **item) const;
 		QPoint _mousePos;
 };
 
