@@ -30,7 +30,6 @@
 #include <kwallet.h>
 
 #include <QCheckBox>
-#include <q3listview.h>
 #include <QPushButton>
 #include <QVBoxLayout>
 #include <ktoolinvocation.h>
@@ -73,9 +72,10 @@ KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList& args)
 	connect(_wcw->_newLocalWallet, SIGNAL(clicked()), this, SLOT(newLocalWallet()));
 	connect(_wcw->_localWallet, SIGNAL(activated(int)), this, SLOT(configChanged()));
 	connect(_wcw->_defaultWallet, SIGNAL(activated(int)), this, SLOT(configChanged()));
-	connect(_wcw->_accessList, SIGNAL(contextMenuRequested(Q3ListViewItem*, const QPoint&, int)), this, SLOT(contextMenuRequested(Q3ListViewItem*, const QPoint&, int)));
+	connect(_wcw->_accessList, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(customContextMenuRequested(const QPoint&)));
 
 	_wcw->_accessList->setAllColumnsShowFocus(true);
+	_wcw->_accessList->setContextMenuPolicy(Qt::CustomContextMenu);
 	updateWalletLists();
 
 	if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QLatin1String( "org.kde.kwalletmanager" ))) {
@@ -90,7 +90,7 @@ KWalletConfig::~KWalletConfig() {
 
 
 void KWalletConfig::updateWalletLists() {
-        const QString p1( _wcw->_localWallet->currentText() );
+	const QString p1( _wcw->_localWallet->currentText() );
 	const QString p2( _wcw->_defaultWallet->currentText() );
 
 	_wcw->_localWallet->clear();
@@ -100,12 +100,14 @@ void KWalletConfig::updateWalletLists() {
 	_wcw->_localWallet->addItems(wl);
 	_wcw->_defaultWallet->addItems(wl);
 
-	if (wl.contains(p1)) {
-		_wcw->_localWallet->setCurrentText(p1);
+	int index = wl.indexOf(p1);
+	if (index != -1) {
+		_wcw->_localWallet->setCurrentIndex(index);
 	}
 
-	if (wl.contains(p2)) {
-		_wcw->_defaultWallet->setCurrentText(p2);
+	index = wl.indexOf(p2);
+	if (index != -1) {
+		_wcw->_defaultWallet->setCurrentIndex(index);
 	}
 }
 
@@ -141,7 +143,7 @@ void KWalletConfig::newLocalWallet() {
 
 	updateWalletLists();
 
-	_wcw->_localWallet->setCurrentText(n);
+	_wcw->_localWallet->setCurrentIndex(_wcw->_localWallet->findText(n));
 
 	emit changed(true);
 }
@@ -155,7 +157,7 @@ void KWalletConfig::newNetworkWallet() {
 
 	updateWalletLists();
 
-	_wcw->_defaultWallet->setCurrentText(n);
+	_wcw->_defaultWallet->setCurrentIndex(_wcw->_defaultWallet->findText(n));
 
 	emit changed(true);
 }
@@ -187,13 +189,13 @@ void KWalletConfig::load() {
 	_wcw->_closeIdle->setChecked(config.readEntry("Close When Idle", false));
 	_wcw->_idleTime->setValue(config.readEntry("Idle Timeout", 10));
 	if (config.hasKey("Default Wallet")) {
-		_wcw->_defaultWallet->setCurrentText(config.readEntry("Default Wallet"));
+		_wcw->_defaultWallet->setItemText(_wcw->_defaultWallet->currentIndex(), config.readEntry("Default Wallet"));
 	} else {
 		_wcw->_defaultWallet->setCurrentIndex(0);
 	}
 	if (config.hasKey("Local Wallet")) {
 		_wcw->_localWalletSelected->setChecked( !config.readEntry("Use One Wallet", false) );
-		_wcw->_localWallet->setCurrentText(config.readEntry("Local Wallet"));
+		_wcw->_localWallet->setItemText(_wcw->_defaultWallet->currentIndex(), config.readEntry("Local Wallet"));
 	} else {
 		_wcw->_localWalletSelected->setChecked(false);
 	}
@@ -206,21 +208,22 @@ void KWalletConfig::load() {
 		const QStringList apps = aa.readEntry(*i,QStringList());
 		const QStringList denyapps = ad.readEntry(*i, QStringList());
 		denykeys.removeAll(*i);
-		Q3ListViewItem *lvi = new Q3ListViewItem(_wcw->_accessList, *i);
+		QTreeWidgetItem *twi = new QTreeWidgetItem(_wcw->_accessList, QStringList() << *i);
 		for (QStringList::const_iterator j = apps.begin(); j != apps.end(); ++j) {
-			new Q3ListViewItem(lvi, QString(), *j, i18n("Always Allow"));
+			new QTreeWidgetItem(twi, QStringList() << QString() << *j << i18n("Always Allow"));
 		}
 		for (QStringList::const_iterator j = denyapps.begin(); j != denyapps.end(); ++j) {
-			new Q3ListViewItem(lvi, QString(), *j, i18n("Always Deny"));
+			new QTreeWidgetItem(twi, QStringList() << QString() << *j << i18n("Always Deny"));
 		}
 	}
 	for (QStringList::const_iterator i = denykeys.constBegin(); i != denykeys.constEnd(); ++i) {
 		const QStringList denyapps = ad.readEntry(*i,QStringList());
-		Q3ListViewItem *lvi = new Q3ListViewItem(_wcw->_accessList, *i);
+		QTreeWidgetItem *twi = new QTreeWidgetItem(_wcw->_accessList, QStringList() << *i);
 		for (QStringList::const_iterator j = denyapps.begin(); j != denyapps.end(); ++j) {
-			new Q3ListViewItem(lvi, QString(), *j, i18n("Always Deny"));
+			new QTreeWidgetItem(twi, QStringList() << QString() << *j << i18n("Always Deny"));
 		}
 	}
+	_wcw->_accessList->header()->setResizeMode(QHeaderView::ResizeToContents);
 	emit changed(false);
 }
 
@@ -253,25 +256,29 @@ void KWalletConfig::save() {
 	_cfg->deleteGroup("Auto Allow");
 	_cfg->deleteGroup("Auto Deny");
 	config  = _cfg->group("Auto Allow");
-	for (Q3ListViewItem *i = _wcw->_accessList->firstChild(); i; i = i->nextSibling()) {
+	for (int i = 0; i < _wcw->_accessList->topLevelItemCount(); ++i) {
+		QTreeWidgetItem *parentItem = _wcw->_accessList->topLevelItem(i);
 		QStringList al;
-		for (Q3ListViewItem *j = i->firstChild(); j; j = j->nextSibling()) {
-			if (j->text(2) == i18n("Always Allow")) {
-				al << j->text(1);
+		for (int j = 0; j < parentItem->childCount(); ++j) {
+			QTreeWidgetItem *childItem = parentItem->child(j);
+			if (childItem->text(2) == i18n("Always Allow")) {
+				al << childItem->text(1);
 			}
 		}
-		config.writeEntry(i->text(0), al);
+		config.writeEntry(parentItem->text(0), al);
 	}
 
 	config = _cfg->group("Auto Deny");
-	for (Q3ListViewItem *i = _wcw->_accessList->firstChild(); i; i = i->nextSibling()) {
+	for (int i = 0; i < _wcw->_accessList->topLevelItemCount(); ++i) {
+		QTreeWidgetItem *parentItem = _wcw->_accessList->topLevelItem(i);
 		QStringList al;
-		for (Q3ListViewItem *j = i->firstChild(); j; j = j->nextSibling()) {
-			if (j->text(2) == i18n("Always Deny")) {
-				al << j->text(1);
+		for (int j = 0; j < parentItem->childCount(); ++j) {
+			QTreeWidgetItem *childItem = parentItem->child(j);
+			if (childItem->text(2) == i18n("Always Deny")) {
+				al << childItem->text(1);
 			}
 		}
-		config.writeEntry(i->text(0), al);
+		config.writeEntry(parentItem->text(0), al);
 	}
 
 	_cfg->sync();
@@ -307,22 +314,22 @@ QString KWalletConfig::quickHelp() const {
 }
 
 
-void KWalletConfig::contextMenuRequested(Q3ListViewItem *item, const QPoint& pos, int col) {
-	Q_UNUSED(col)
+void KWalletConfig::customContextMenuRequested(const QPoint& pos) {
+	QTreeWidgetItem *item = _wcw->_accessList->itemAt(pos);
 	if (item && item->parent()) {
 		KMenu *m = new KMenu(this);
 		m->addTitle(item->parent()->text(0));
 		m->addAction( i18n("&Delete" ), this, SLOT(deleteEntry()), Qt::Key_Delete);
-		m->exec(pos);
-                delete m;
+		m->exec(_wcw->_accessList->mapToGlobal(pos));
+		delete m;
 	}
 }
 
 
 void KWalletConfig::deleteEntry() {
-	Q3ListViewItem *item = _wcw->_accessList->selectedItem();
-	if (item) {
-		delete item;
+	QList<QTreeWidgetItem*> items = _wcw->_accessList->selectedItems();
+	if (items.count() == 1 && items[0] ) {
+		delete items[0];
 		emit changed(true);
 	}
 }
